﻿#region

using System;
using System.IO;
using System.Windows.Forms;
using SystemFileSample1.MyClass.Relation;

#endregion

namespace SystemFileSample1.MyClass.Seller
{
    public class SellerDataAccess
    {
        public Seller Seller { get; set; }

        public bool Insert()
        {
            if (SellerErrorDetection.SellerCheck(Seller))
            {
                SellerInsert();
                return (true);
            }
            return (false);
        }


        public bool Delete()
        {
            if (!SellerErrorDetection.CodeCheck(Seller.Code))
            {
                MessageBox.Show(@"این کد فروشنده موجود نیست", @"خطا", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return (false);
            }

            if (Relations.RelatSellerToPartSell)
            {
                if (SellerErrorDetection.CheckInPartSell(Seller.Code) && Relations.RelatSellerToPartSellDelete)
                {
                    SellerErrorDetection.DeleteSellerInPartSell(Seller.Code);
                }
                else if (SellerErrorDetection.CheckInPartSell(Seller.Code) && !Relations.RelatSellerToPartSellDelete)
                {
                    MessageBox.Show(@"این فروشنده به دلیل رابطه داشتن با جدول فروش  قابل حذف نیست", @"خطا",
                                    MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return (false);
                }
            }

            Sellers.AllSellers.RemoveAll(d => d.Code == Seller.Code);

            SellerErrorDetection.SellerFileRefreshe();

            return (true);
        }

        public bool Update(string sellerLastCode)
        {
            if (!SellerErrorDetection.CodeCheck(sellerLastCode))
            {
                MessageBox.Show(@"این کد فروشنده موجود نیست", @"خطا", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return (false);
            }
            if (SellerErrorDetection.CodeCheck(Seller.Code) && sellerLastCode != Seller.Code)
            {
                MessageBox.Show(@"این کد فروشنده موجود است", @"خطا", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return (false);
            }
            if (Relations.RelatSellerToPartSell)
            {
                if (SellerErrorDetection.CheckInPartSell(sellerLastCode) && Relations.RelatSellerToPartSellUpdate)
                {
                    SellerErrorDetection.UpdateSellerInPartSell(sellerLastCode, Seller.Code);
                }
                else if (SellerErrorDetection.CheckInPartSell(sellerLastCode) &&
                         !Relations.RelatSellerToPartSellUpdate)
                {
                    MessageBox.Show(@"این فروشنده به دلیل رابطه داشتن با جدول فروش  قابل ویرایش نیست", @"خطا",
                                    MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return (false);
                }
            }

            Sellers.AllSellers.Find(d => d.Code == sellerLastCode).Name = Seller.Name;
            Sellers.AllSellers.Find(d => d.Code == sellerLastCode).Family = Seller.Family;
            Sellers.AllSellers.Find(d => d.Code == sellerLastCode).Code = Seller.Code;

            SellerErrorDetection.SellerFileRefreshe();

            return (true);
        }


        private void SellerInsert()
        {
            try
            {
                if (!SellerErrorDetection.SellerFileExist())
                {
                    MessageBox.Show(@"فایل مورد نظر برای ذخیره سازی وجود ندارد", @"خطا", MessageBoxButtons.OK,
                                    MessageBoxIcon.Error);
                }
                else
                {
                    using (var sellerFile = File.AppendText(Application.StartupPath + "/Seller.txt"))
                    {
                        sellerFile.Write(Seller.Name + ";" + Seller.Family + ";" + Seller.Code + "@");
                    }
                }
            }
            catch (Exception)
            {
                MessageBox.Show(@"خطایی در زمان اجرای عملیات ذخیره سازی رخ داده است", @"خطا", MessageBoxButtons.OK,
                                MessageBoxIcon.Error);
            }
        }
    }
}